var annotated_dup =
[
    [ "gko", "namespacegko.html", [
      [ "accessor", "namespacegko_1_1accessor.html", [
        [ "abs_operation", "structgko_1_1accessor_1_1abs__operation.html", null ],
        [ "abs_operaton", "structgko_1_1accessor_1_1abs__operaton.html", null ],
        [ "add", "structgko_1_1accessor_1_1add.html", null ],
        [ "bitwise_and", "structgko_1_1accessor_1_1bitwise__and.html", null ],
        [ "bitwise_not", "structgko_1_1accessor_1_1bitwise__not.html", null ],
        [ "bitwise_or", "structgko_1_1accessor_1_1bitwise__or.html", null ],
        [ "bitwise_xor", "structgko_1_1accessor_1_1bitwise__xor.html", null ],
        [ "conj_operation", "structgko_1_1accessor_1_1conj__operation.html", null ],
        [ "conj_operaton", "structgko_1_1accessor_1_1conj__operaton.html", null ],
        [ "div", "structgko_1_1accessor_1_1div.html", null ],
        [ "equal", "structgko_1_1accessor_1_1equal.html", null ],
        [ "greater", "structgko_1_1accessor_1_1greater.html", null ],
        [ "greater_or_equal", "structgko_1_1accessor_1_1greater__or__equal.html", null ],
        [ "imag_operation", "structgko_1_1accessor_1_1imag__operation.html", null ],
        [ "imag_operaton", "structgko_1_1accessor_1_1imag__operaton.html", null ],
        [ "left_shift", "structgko_1_1accessor_1_1left__shift.html", null ],
        [ "less", "structgko_1_1accessor_1_1less.html", null ],
        [ "less_or_equal", "structgko_1_1accessor_1_1less__or__equal.html", null ],
        [ "logical_and", "structgko_1_1accessor_1_1logical__and.html", null ],
        [ "logical_not", "structgko_1_1accessor_1_1logical__not.html", null ],
        [ "logical_or", "structgko_1_1accessor_1_1logical__or.html", null ],
        [ "max_operation", "structgko_1_1accessor_1_1max__operation.html", null ],
        [ "min_operation", "structgko_1_1accessor_1_1min__operation.html", null ],
        [ "mmul_operation", "structgko_1_1accessor_1_1mmul__operation.html", null ],
        [ "mod", "structgko_1_1accessor_1_1mod.html", null ],
        [ "mul", "structgko_1_1accessor_1_1mul.html", null ],
        [ "not_equal", "structgko_1_1accessor_1_1not__equal.html", null ],
        [ "one_operation", "structgko_1_1accessor_1_1one__operation.html", null ],
        [ "one_operaton", "structgko_1_1accessor_1_1one__operaton.html", null ],
        [ "real_operation", "structgko_1_1accessor_1_1real__operation.html", null ],
        [ "real_operaton", "structgko_1_1accessor_1_1real__operaton.html", null ],
        [ "right_shift", "structgko_1_1accessor_1_1right__shift.html", null ],
        [ "row_major", "classgko_1_1accessor_1_1row__major.html", "classgko_1_1accessor_1_1row__major" ],
        [ "squared_norm_operation", "structgko_1_1accessor_1_1squared__norm__operation.html", null ],
        [ "squared_norm_operaton", "structgko_1_1accessor_1_1squared__norm__operaton.html", null ],
        [ "sub", "structgko_1_1accessor_1_1sub.html", null ],
        [ "transpose_operation", "structgko_1_1accessor_1_1transpose__operation.html", null ],
        [ "unary_minus", "structgko_1_1accessor_1_1unary__minus.html", null ],
        [ "unary_plus", "structgko_1_1accessor_1_1unary__plus.html", null ],
        [ "zero_operation", "structgko_1_1accessor_1_1zero__operation.html", null ]
      ] ],
      [ "batch", null, [
        [ "log", "namespacegko_1_1batch_1_1log.html", [
          [ "BatchConvergence", "classgko_1_1batch_1_1log_1_1BatchConvergence.html", "classgko_1_1batch_1_1log_1_1BatchConvergence" ]
        ] ],
        [ "matrix", null, [
          [ "Csr", "classgko_1_1batch_1_1matrix_1_1Csr.html", "classgko_1_1batch_1_1matrix_1_1Csr" ],
          [ "Dense", "classgko_1_1batch_1_1matrix_1_1Dense.html", "classgko_1_1batch_1_1matrix_1_1Dense" ],
          [ "Ell", "classgko_1_1batch_1_1matrix_1_1Ell.html", "classgko_1_1batch_1_1matrix_1_1Ell" ],
          [ "Identity", "classgko_1_1batch_1_1matrix_1_1Identity.html", "classgko_1_1batch_1_1matrix_1_1Identity" ]
        ] ],
        [ "preconditioner", null, [
          [ "Jacobi", "classgko_1_1batch_1_1preconditioner_1_1Jacobi.html", "classgko_1_1batch_1_1preconditioner_1_1Jacobi" ]
        ] ],
        [ "solver", null, [
          [ "BatchSolver", "classgko_1_1batch_1_1solver_1_1BatchSolver.html", "classgko_1_1batch_1_1solver_1_1BatchSolver" ],
          [ "Bicgstab", "classgko_1_1batch_1_1solver_1_1Bicgstab.html", "classgko_1_1batch_1_1solver_1_1Bicgstab" ],
          [ "Cg", "classgko_1_1batch_1_1solver_1_1Cg.html", "classgko_1_1batch_1_1solver_1_1Cg" ],
          [ "enable_preconditioned_iterative_solver_factory_parameters", "structgko_1_1batch_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters.html", "structgko_1_1batch_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters" ],
          [ "EnableBatchSolver", "classgko_1_1batch_1_1solver_1_1EnableBatchSolver.html", null ]
        ] ],
        [ "BatchLinOp", "classgko_1_1batch_1_1BatchLinOp.html", "classgko_1_1batch_1_1BatchLinOp" ],
        [ "BatchLinOpFactory", "classgko_1_1batch_1_1BatchLinOpFactory.html", null ],
        [ "EnableBatchLinOp", "classgko_1_1batch_1_1EnableBatchLinOp.html", null ],
        [ "MultiVector", "classgko_1_1batch_1_1MultiVector.html", "classgko_1_1batch_1_1MultiVector" ]
      ] ],
      [ "config", null, [
        [ "pnode", "classgko_1_1config_1_1pnode.html", "classgko_1_1config_1_1pnode" ],
        [ "registry", "classgko_1_1config_1_1registry.html", "classgko_1_1config_1_1registry" ],
        [ "type_descriptor", "classgko_1_1config_1_1type__descriptor.html", "classgko_1_1config_1_1type__descriptor" ]
      ] ],
      [ "experimental", null, [
        [ "distributed", "namespacegko_1_1experimental_1_1distributed.html", [
          [ "preconditioner", "namespacegko_1_1experimental_1_1distributed_1_1preconditioner.html", [
            [ "Schwarz", "classgko_1_1experimental_1_1distributed_1_1preconditioner_1_1Schwarz.html", "classgko_1_1experimental_1_1distributed_1_1preconditioner_1_1Schwarz" ]
          ] ],
          [ "DistributedBase", "classgko_1_1experimental_1_1distributed_1_1DistributedBase.html", "classgko_1_1experimental_1_1distributed_1_1DistributedBase" ],
          [ "index_map", "classgko_1_1experimental_1_1distributed_1_1index__map.html", "classgko_1_1experimental_1_1distributed_1_1index__map" ],
          [ "Matrix", "classgko_1_1experimental_1_1distributed_1_1Matrix.html", "classgko_1_1experimental_1_1distributed_1_1Matrix" ],
          [ "Partition", "classgko_1_1experimental_1_1distributed_1_1Partition.html", "classgko_1_1experimental_1_1distributed_1_1Partition" ],
          [ "RowGatherer", "classgko_1_1experimental_1_1distributed_1_1RowGatherer.html", "classgko_1_1experimental_1_1distributed_1_1RowGatherer" ],
          [ "Vector", "classgko_1_1experimental_1_1distributed_1_1Vector.html", "classgko_1_1experimental_1_1distributed_1_1Vector" ]
        ] ],
        [ "factorization", null, [
          [ "Cholesky", "classgko_1_1experimental_1_1factorization_1_1Cholesky.html", "classgko_1_1experimental_1_1factorization_1_1Cholesky" ],
          [ "Factorization", "classgko_1_1experimental_1_1factorization_1_1Factorization.html", "classgko_1_1experimental_1_1factorization_1_1Factorization" ],
          [ "Lu", "classgko_1_1experimental_1_1factorization_1_1Lu.html", "classgko_1_1experimental_1_1factorization_1_1Lu" ]
        ] ],
        [ "mpi", "namespacegko_1_1experimental_1_1mpi.html", [
          [ "CollectiveCommunicator", "classgko_1_1experimental_1_1mpi_1_1CollectiveCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1CollectiveCommunicator" ],
          [ "communicator", "classgko_1_1experimental_1_1mpi_1_1communicator.html", "classgko_1_1experimental_1_1mpi_1_1communicator" ],
          [ "contiguous_type", "classgko_1_1experimental_1_1mpi_1_1contiguous__type.html", "classgko_1_1experimental_1_1mpi_1_1contiguous__type" ],
          [ "DenseCommunicator", "classgko_1_1experimental_1_1mpi_1_1DenseCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1DenseCommunicator" ],
          [ "environment", "classgko_1_1experimental_1_1mpi_1_1environment.html", "classgko_1_1experimental_1_1mpi_1_1environment" ],
          [ "NeighborhoodCommunicator", "classgko_1_1experimental_1_1mpi_1_1NeighborhoodCommunicator.html", "classgko_1_1experimental_1_1mpi_1_1NeighborhoodCommunicator" ],
          [ "request", "classgko_1_1experimental_1_1mpi_1_1request.html", "classgko_1_1experimental_1_1mpi_1_1request" ],
          [ "status", "structgko_1_1experimental_1_1mpi_1_1status.html", "structgko_1_1experimental_1_1mpi_1_1status" ],
          [ "type_impl", "structgko_1_1experimental_1_1mpi_1_1type__impl.html", null ],
          [ "type_impl< char >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01char_01_4.html", null ],
          [ "type_impl< double >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01double_01_4.html", null ],
          [ "type_impl< float >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01float_01_4.html", null ],
          [ "type_impl< int >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01int_01_4.html", null ],
          [ "type_impl< long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01_4.html", null ],
          [ "type_impl< long double >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01double_01_4.html", null ],
          [ "type_impl< long long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01long_01long_01_4.html", null ],
          [ "type_impl< unsigned >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01_4.html", null ],
          [ "type_impl< unsigned char >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01char_01_4.html", null ],
          [ "type_impl< unsigned long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01long_01_4.html", null ],
          [ "type_impl< unsigned long long >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01long_01long_01_4.html", null ],
          [ "type_impl< unsigned short >", "structgko_1_1experimental_1_1mpi_1_1type__impl_3_01unsigned_01short_01_4.html", null ],
          [ "window", "classgko_1_1experimental_1_1mpi_1_1window.html", "classgko_1_1experimental_1_1mpi_1_1window" ]
        ] ],
        [ "reorder", "namespacegko_1_1experimental_1_1reorder.html", [
          [ "Amd", "classgko_1_1experimental_1_1reorder_1_1Amd.html", "classgko_1_1experimental_1_1reorder_1_1Amd" ],
          [ "Mc64", "classgko_1_1experimental_1_1reorder_1_1Mc64.html", "classgko_1_1experimental_1_1reorder_1_1Mc64" ],
          [ "Rcm", "classgko_1_1experimental_1_1reorder_1_1Rcm.html", "classgko_1_1experimental_1_1reorder_1_1Rcm" ],
          [ "ScaledReordered", "classgko_1_1experimental_1_1reorder_1_1ScaledReordered.html", "classgko_1_1experimental_1_1reorder_1_1ScaledReordered" ]
        ] ],
        [ "solver", null, [
          [ "Direct", "classgko_1_1experimental_1_1solver_1_1Direct.html", "classgko_1_1experimental_1_1solver_1_1Direct" ]
        ] ]
      ] ],
      [ "factorization", "namespacegko_1_1factorization.html", [
        [ "Ic", "classgko_1_1factorization_1_1Ic.html", "classgko_1_1factorization_1_1Ic" ],
        [ "Ilu", "classgko_1_1factorization_1_1Ilu.html", "classgko_1_1factorization_1_1Ilu" ],
        [ "ParIc", "classgko_1_1factorization_1_1ParIc.html", "classgko_1_1factorization_1_1ParIc" ],
        [ "ParIct", "classgko_1_1factorization_1_1ParIct.html", "classgko_1_1factorization_1_1ParIct" ],
        [ "ParIlu", "classgko_1_1factorization_1_1ParIlu.html", "classgko_1_1factorization_1_1ParIlu" ],
        [ "ParIlut", "classgko_1_1factorization_1_1ParIlut.html", "classgko_1_1factorization_1_1ParIlut" ]
      ] ],
      [ "log", "namespacegko_1_1log.html", [
        [ "Convergence", "classgko_1_1log_1_1Convergence.html", "classgko_1_1log_1_1Convergence" ],
        [ "criterion_data", "structgko_1_1log_1_1criterion__data.html", null ],
        [ "EnableLogging", "classgko_1_1log_1_1EnableLogging.html", "classgko_1_1log_1_1EnableLogging" ],
        [ "executor_data", "structgko_1_1log_1_1executor__data.html", null ],
        [ "iteration_complete_data", "structgko_1_1log_1_1iteration__complete__data.html", null ],
        [ "linop_data", "structgko_1_1log_1_1linop__data.html", null ],
        [ "linop_factory_data", "structgko_1_1log_1_1linop__factory__data.html", null ],
        [ "Loggable", "classgko_1_1log_1_1Loggable.html", "classgko_1_1log_1_1Loggable" ],
        [ "Logger", "classgko_1_1log_1_1Logger.html", "classgko_1_1log_1_1Logger" ],
        [ "operation_data", "structgko_1_1log_1_1operation__data.html", null ],
        [ "Papi", "classgko_1_1log_1_1Papi.html", "classgko_1_1log_1_1Papi" ],
        [ "PerformanceHint", "classgko_1_1log_1_1PerformanceHint.html", "classgko_1_1log_1_1PerformanceHint" ],
        [ "polymorphic_object_data", "structgko_1_1log_1_1polymorphic__object__data.html", null ],
        [ "ProfilerHook", "classgko_1_1log_1_1ProfilerHook.html", "classgko_1_1log_1_1ProfilerHook" ],
        [ "profiling_scope_guard", "classgko_1_1log_1_1profiling__scope__guard.html", "classgko_1_1log_1_1profiling__scope__guard" ],
        [ "Record", "classgko_1_1log_1_1Record.html", "classgko_1_1log_1_1Record" ],
        [ "SolverProgress", "classgko_1_1log_1_1SolverProgress.html", null ],
        [ "Stream", "classgko_1_1log_1_1Stream.html", "classgko_1_1log_1_1Stream" ]
      ] ],
      [ "matrix", "namespacegko_1_1matrix.html", [
        [ "Coo", "classgko_1_1matrix_1_1Coo.html", "classgko_1_1matrix_1_1Coo" ],
        [ "CooBuilder", "classgko_1_1matrix_1_1CooBuilder.html", null ],
        [ "Csr", "classgko_1_1matrix_1_1Csr.html", "classgko_1_1matrix_1_1Csr" ],
        [ "CsrBuilder", "classgko_1_1matrix_1_1CsrBuilder.html", null ],
        [ "Dense", "classgko_1_1matrix_1_1Dense.html", "classgko_1_1matrix_1_1Dense" ],
        [ "Diagonal", "classgko_1_1matrix_1_1Diagonal.html", "classgko_1_1matrix_1_1Diagonal" ],
        [ "Ell", "classgko_1_1matrix_1_1Ell.html", "classgko_1_1matrix_1_1Ell" ],
        [ "Fbcsr", "classgko_1_1matrix_1_1Fbcsr.html", "classgko_1_1matrix_1_1Fbcsr" ],
        [ "FbcsrBuilder", "classgko_1_1matrix_1_1FbcsrBuilder.html", null ],
        [ "Fft", "classgko_1_1matrix_1_1Fft.html", "classgko_1_1matrix_1_1Fft" ],
        [ "Fft2", "classgko_1_1matrix_1_1Fft2.html", "classgko_1_1matrix_1_1Fft2" ],
        [ "Fft3", "classgko_1_1matrix_1_1Fft3.html", "classgko_1_1matrix_1_1Fft3" ],
        [ "Hybrid", "classgko_1_1matrix_1_1Hybrid.html", "classgko_1_1matrix_1_1Hybrid" ],
        [ "Identity", "classgko_1_1matrix_1_1Identity.html", "classgko_1_1matrix_1_1Identity" ],
        [ "IdentityFactory", "classgko_1_1matrix_1_1IdentityFactory.html", null ],
        [ "Permutation", "classgko_1_1matrix_1_1Permutation.html", "classgko_1_1matrix_1_1Permutation" ],
        [ "RowGatherer", "classgko_1_1matrix_1_1RowGatherer.html", "classgko_1_1matrix_1_1RowGatherer" ],
        [ "ScaledPermutation", "classgko_1_1matrix_1_1ScaledPermutation.html", "classgko_1_1matrix_1_1ScaledPermutation" ],
        [ "Sellp", "classgko_1_1matrix_1_1Sellp.html", "classgko_1_1matrix_1_1Sellp" ],
        [ "SparsityCsr", "classgko_1_1matrix_1_1SparsityCsr.html", "classgko_1_1matrix_1_1SparsityCsr" ]
      ] ],
      [ "multigrid", "namespacegko_1_1multigrid.html", [
        [ "EnableMultigridLevel", "classgko_1_1multigrid_1_1EnableMultigridLevel.html", "classgko_1_1multigrid_1_1EnableMultigridLevel" ],
        [ "FixedCoarsening", "classgko_1_1multigrid_1_1FixedCoarsening.html", "classgko_1_1multigrid_1_1FixedCoarsening" ],
        [ "MultigridLevel", "classgko_1_1multigrid_1_1MultigridLevel.html", "classgko_1_1multigrid_1_1MultigridLevel" ],
        [ "Pgm", "classgko_1_1multigrid_1_1Pgm.html", "classgko_1_1multigrid_1_1Pgm" ]
      ] ],
      [ "preconditioner", "namespacegko_1_1preconditioner.html", [
        [ "block_interleaved_storage_scheme", "structgko_1_1preconditioner_1_1block__interleaved__storage__scheme.html", "structgko_1_1preconditioner_1_1block__interleaved__storage__scheme" ],
        [ "GaussSeidel", "classgko_1_1preconditioner_1_1GaussSeidel.html", "classgko_1_1preconditioner_1_1GaussSeidel" ],
        [ "Ic", "classgko_1_1preconditioner_1_1Ic.html", "classgko_1_1preconditioner_1_1Ic" ],
        [ "Ilu", "classgko_1_1preconditioner_1_1Ilu.html", "classgko_1_1preconditioner_1_1Ilu" ],
        [ "Isai", "classgko_1_1preconditioner_1_1Isai.html", "classgko_1_1preconditioner_1_1Isai" ],
        [ "Jacobi", "classgko_1_1preconditioner_1_1Jacobi.html", "classgko_1_1preconditioner_1_1Jacobi" ],
        [ "Sor", "classgko_1_1preconditioner_1_1Sor.html", "classgko_1_1preconditioner_1_1Sor" ]
      ] ],
      [ "reorder", "namespacegko_1_1reorder.html", [
        [ "Rcm", "classgko_1_1reorder_1_1Rcm.html", "classgko_1_1reorder_1_1Rcm" ],
        [ "ReorderingBase", "classgko_1_1reorder_1_1ReorderingBase.html", null ],
        [ "ReorderingBaseArgs", "structgko_1_1reorder_1_1ReorderingBaseArgs.html", null ]
      ] ],
      [ "solver", "namespacegko_1_1solver.html", [
        [ "ApplyWithInitialGuess", "classgko_1_1solver_1_1ApplyWithInitialGuess.html", null ],
        [ "Bicg", "classgko_1_1solver_1_1Bicg.html", "classgko_1_1solver_1_1Bicg" ],
        [ "Bicgstab", "classgko_1_1solver_1_1Bicgstab.html", "classgko_1_1solver_1_1Bicgstab" ],
        [ "CbGmres", "classgko_1_1solver_1_1CbGmres.html", "classgko_1_1solver_1_1CbGmres" ],
        [ "Cg", "classgko_1_1solver_1_1Cg.html", "classgko_1_1solver_1_1Cg" ],
        [ "Cgs", "classgko_1_1solver_1_1Cgs.html", "classgko_1_1solver_1_1Cgs" ],
        [ "Chebyshev", "classgko_1_1solver_1_1Chebyshev.html", "classgko_1_1solver_1_1Chebyshev" ],
        [ "enable_iterative_solver_factory_parameters", "structgko_1_1solver_1_1enable__iterative__solver__factory__parameters.html", "structgko_1_1solver_1_1enable__iterative__solver__factory__parameters" ],
        [ "enable_preconditioned_iterative_solver_factory_parameters", "structgko_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters.html", "structgko_1_1solver_1_1enable__preconditioned__iterative__solver__factory__parameters" ],
        [ "EnableApplyWithInitialGuess", "classgko_1_1solver_1_1EnableApplyWithInitialGuess.html", null ],
        [ "EnableIterativeBase", "classgko_1_1solver_1_1EnableIterativeBase.html", "classgko_1_1solver_1_1EnableIterativeBase" ],
        [ "EnablePreconditionable", "classgko_1_1solver_1_1EnablePreconditionable.html", "classgko_1_1solver_1_1EnablePreconditionable" ],
        [ "EnablePreconditionedIterativeSolver", "classgko_1_1solver_1_1EnablePreconditionedIterativeSolver.html", null ],
        [ "EnableSolverBase", "classgko_1_1solver_1_1EnableSolverBase.html", "classgko_1_1solver_1_1EnableSolverBase" ],
        [ "Fcg", "classgko_1_1solver_1_1Fcg.html", "classgko_1_1solver_1_1Fcg" ],
        [ "Gcr", "classgko_1_1solver_1_1Gcr.html", "classgko_1_1solver_1_1Gcr" ],
        [ "Gmres", "classgko_1_1solver_1_1Gmres.html", "classgko_1_1solver_1_1Gmres" ],
        [ "has_with_criteria", "structgko_1_1solver_1_1has__with__criteria.html", null ],
        [ "Idr", "classgko_1_1solver_1_1Idr.html", "classgko_1_1solver_1_1Idr" ],
        [ "Ir", "classgko_1_1solver_1_1Ir.html", "classgko_1_1solver_1_1Ir" ],
        [ "IterativeBase", "classgko_1_1solver_1_1IterativeBase.html", "classgko_1_1solver_1_1IterativeBase" ],
        [ "LowerTrs", "classgko_1_1solver_1_1LowerTrs.html", "classgko_1_1solver_1_1LowerTrs" ],
        [ "Minres", "classgko_1_1solver_1_1Minres.html", "classgko_1_1solver_1_1Minres" ],
        [ "Multigrid", "classgko_1_1solver_1_1Multigrid.html", "classgko_1_1solver_1_1Multigrid" ],
        [ "PipeCg", "classgko_1_1solver_1_1PipeCg.html", "classgko_1_1solver_1_1PipeCg" ],
        [ "SolverBase", "classgko_1_1solver_1_1SolverBase.html", "classgko_1_1solver_1_1SolverBase" ],
        [ "UpperTrs", "classgko_1_1solver_1_1UpperTrs.html", "classgko_1_1solver_1_1UpperTrs" ],
        [ "workspace_traits", "structgko_1_1solver_1_1workspace__traits.html", null ],
        [ "workspace_traits< Bicg< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Bicg_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Bicgstab< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Bicgstab_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Cg< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Cg_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Cgs< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Cgs_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Chebyshev< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Chebyshev_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Fcg< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Fcg_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Gcr< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Gcr_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< gko::experimental::solver::Direct< ValueType, IndexType > >", "structgko_1_1solver_1_1workspace__traits_3_01gko_1_1experimental_1_1solver_1_1Direct_3_01ValueType_00_01IndexType_01_4_01_4.html", null ],
        [ "workspace_traits< Gmres< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Gmres_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Idr< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Idr_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Ir< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Ir_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< LowerTrs< ValueType, IndexType > >", "structgko_1_1solver_1_1workspace__traits_3_01LowerTrs_3_01ValueType_00_01IndexType_01_4_01_4.html", null ],
        [ "workspace_traits< Minres< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01Minres_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< Multigrid >", "structgko_1_1solver_1_1workspace__traits_3_01Multigrid_01_4.html", null ],
        [ "workspace_traits< PipeCg< ValueType > >", "structgko_1_1solver_1_1workspace__traits_3_01PipeCg_3_01ValueType_01_4_01_4.html", null ],
        [ "workspace_traits< UpperTrs< ValueType, IndexType > >", "structgko_1_1solver_1_1workspace__traits_3_01UpperTrs_3_01ValueType_00_01IndexType_01_4_01_4.html", null ]
      ] ],
      [ "stop", "namespacegko_1_1stop.html", [
        [ "AbsoluteResidualNorm", "classgko_1_1stop_1_1AbsoluteResidualNorm.html", "classgko_1_1stop_1_1AbsoluteResidualNorm" ],
        [ "Combined", "classgko_1_1stop_1_1Combined.html", "classgko_1_1stop_1_1Combined" ],
        [ "Criterion", "classgko_1_1stop_1_1Criterion.html", "classgko_1_1stop_1_1Criterion" ],
        [ "CriterionArgs", "structgko_1_1stop_1_1CriterionArgs.html", null ],
        [ "ImplicitResidualNorm", "classgko_1_1stop_1_1ImplicitResidualNorm.html", "classgko_1_1stop_1_1ImplicitResidualNorm" ],
        [ "Iteration", "classgko_1_1stop_1_1Iteration.html", "classgko_1_1stop_1_1Iteration" ],
        [ "RelativeResidualNorm", "classgko_1_1stop_1_1RelativeResidualNorm.html", "classgko_1_1stop_1_1RelativeResidualNorm" ],
        [ "ResidualNorm", "classgko_1_1stop_1_1ResidualNorm.html", "classgko_1_1stop_1_1ResidualNorm" ],
        [ "ResidualNormBase", "classgko_1_1stop_1_1ResidualNormBase.html", null ],
        [ "ResidualNormReduction", "classgko_1_1stop_1_1ResidualNormReduction.html", "classgko_1_1stop_1_1ResidualNormReduction" ],
        [ "Time", "classgko_1_1stop_1_1Time.html", "classgko_1_1stop_1_1Time" ]
      ] ],
      [ "syn", "namespacegko_1_1syn.html", [
        [ "range", "structgko_1_1syn_1_1range.html", null ],
        [ "type_list", "structgko_1_1syn_1_1type__list.html", null ],
        [ "value_list", "structgko_1_1syn_1_1value__list.html", null ]
      ] ],
      [ "xstd", "namespacegko_1_1xstd.html", [
        [ "type_identity", "structgko_1_1xstd_1_1type__identity.html", null ]
      ] ],
      [ "AbsoluteComputable", "classgko_1_1AbsoluteComputable.html", "classgko_1_1AbsoluteComputable" ],
      [ "AbstractFactory", "classgko_1_1AbstractFactory.html", "classgko_1_1AbstractFactory" ],
      [ "AllocationError", "classgko_1_1AllocationError.html", "classgko_1_1AllocationError" ],
      [ "Allocator", "classgko_1_1Allocator.html", null ],
      [ "amd_device", "classgko_1_1amd__device.html", null ],
      [ "are_all_integral", "structgko_1_1are__all__integral.html", null ],
      [ "are_all_integral< First, Args... >", "structgko_1_1are__all__integral_3_01First_00_01Args_8_8_8_01_4.html", null ],
      [ "array", "classgko_1_1array.html", "classgko_1_1array" ],
      [ "BadDimension", "classgko_1_1BadDimension.html", "classgko_1_1BadDimension" ],
      [ "batch_dim", "structgko_1_1batch__dim.html", "structgko_1_1batch__dim" ],
      [ "bfloat16", "classgko_1_1bfloat16.html", null ],
      [ "BlockOperator", "classgko_1_1BlockOperator.html", "classgko_1_1BlockOperator" ],
      [ "BlockSizeError", "classgko_1_1BlockSizeError.html", "classgko_1_1BlockSizeError" ],
      [ "Combination", "classgko_1_1Combination.html", "classgko_1_1Combination" ],
      [ "Composition", "classgko_1_1Composition.html", "classgko_1_1Composition" ],
      [ "ConvertibleTo", "classgko_1_1ConvertibleTo.html", "classgko_1_1ConvertibleTo" ],
      [ "CpuAllocator", "classgko_1_1CpuAllocator.html", null ],
      [ "CpuAllocatorBase", "classgko_1_1CpuAllocatorBase.html", null ],
      [ "CpuTimer", "classgko_1_1CpuTimer.html", "classgko_1_1CpuTimer" ],
      [ "cpx_real_type", "structgko_1_1cpx__real__type.html", "structgko_1_1cpx__real__type" ],
      [ "CublasError", "classgko_1_1CublasError.html", "classgko_1_1CublasError" ],
      [ "cuda_stream", "classgko_1_1cuda__stream.html", "classgko_1_1cuda__stream" ],
      [ "CudaAllocator", "classgko_1_1CudaAllocator.html", null ],
      [ "CudaAllocatorBase", "classgko_1_1CudaAllocatorBase.html", null ],
      [ "CudaAsyncAllocator", "classgko_1_1CudaAsyncAllocator.html", "classgko_1_1CudaAsyncAllocator" ],
      [ "CudaError", "classgko_1_1CudaError.html", "classgko_1_1CudaError" ],
      [ "CudaExecutor", "classgko_1_1CudaExecutor.html", "classgko_1_1CudaExecutor" ],
      [ "CudaHostAllocator", "classgko_1_1CudaHostAllocator.html", null ],
      [ "CudaTimer", "classgko_1_1CudaTimer.html", "classgko_1_1CudaTimer" ],
      [ "CudaUnifiedAllocator", "classgko_1_1CudaUnifiedAllocator.html", null ],
      [ "CufftError", "classgko_1_1CufftError.html", "classgko_1_1CufftError" ],
      [ "CurandError", "classgko_1_1CurandError.html", "classgko_1_1CurandError" ],
      [ "CusparseError", "classgko_1_1CusparseError.html", "classgko_1_1CusparseError" ],
      [ "default_converter", "structgko_1_1default__converter.html", "structgko_1_1default__converter" ],
      [ "deferred_factory_parameter", "classgko_1_1deferred__factory__parameter.html", "classgko_1_1deferred__factory__parameter" ],
      [ "device_matrix_data", "classgko_1_1device__matrix__data.html", "classgko_1_1device__matrix__data" ],
      [ "DiagonalExtractable", "classgko_1_1DiagonalExtractable.html", "classgko_1_1DiagonalExtractable" ],
      [ "DiagonalLinOpExtractable", "classgko_1_1DiagonalLinOpExtractable.html", "classgko_1_1DiagonalLinOpExtractable" ],
      [ "dim", "structgko_1_1dim.html", "structgko_1_1dim" ],
      [ "dim< 1u, DimensionType >", "structgko_1_1dim_3_011u_00_01DimensionType_01_4.html", null ],
      [ "DimensionMismatch", "classgko_1_1DimensionMismatch.html", "classgko_1_1DimensionMismatch" ],
      [ "DpcppExecutor", "classgko_1_1DpcppExecutor.html", "classgko_1_1DpcppExecutor" ],
      [ "DpcppTimer", "classgko_1_1DpcppTimer.html", "classgko_1_1DpcppTimer" ],
      [ "enable_parameters_type", "classgko_1_1enable__parameters__type.html", "classgko_1_1enable__parameters__type" ],
      [ "EnableAbsoluteComputation", "classgko_1_1EnableAbsoluteComputation.html", "classgko_1_1EnableAbsoluteComputation" ],
      [ "EnableAbstractPolymorphicObject", "classgko_1_1EnableAbstractPolymorphicObject.html", null ],
      [ "EnableCreateMethod", "classgko_1_1EnableCreateMethod.html", null ],
      [ "EnableDefaultFactory", "classgko_1_1EnableDefaultFactory.html", "classgko_1_1EnableDefaultFactory" ],
      [ "EnableLinOp", "classgko_1_1EnableLinOp.html", null ],
      [ "EnablePolymorphicAssignment", "classgko_1_1EnablePolymorphicAssignment.html", null ],
      [ "EnablePolymorphicObject", "classgko_1_1EnablePolymorphicObject.html", null ],
      [ "err", "structgko_1_1err.html", null ],
      [ "Error", "classgko_1_1Error.html", "classgko_1_1Error" ],
      [ "Executor", "classgko_1_1Executor.html", "classgko_1_1Executor" ],
      [ "executor_deleter", "classgko_1_1executor__deleter.html", "classgko_1_1executor__deleter" ],
      [ "executor_deleter< T[]>", "classgko_1_1executor__deleter_3_01T_0f_0e_4.html", null ],
      [ "half", "classgko_1_1half.html", null ],
      [ "hip_stream", "classgko_1_1hip__stream.html", "classgko_1_1hip__stream" ],
      [ "HipAllocator", "classgko_1_1HipAllocator.html", null ],
      [ "HipAllocatorBase", "classgko_1_1HipAllocatorBase.html", null ],
      [ "HipAsyncAllocator", "classgko_1_1HipAsyncAllocator.html", null ],
      [ "HipblasError", "classgko_1_1HipblasError.html", "classgko_1_1HipblasError" ],
      [ "HipError", "classgko_1_1HipError.html", "classgko_1_1HipError" ],
      [ "HipExecutor", "classgko_1_1HipExecutor.html", "classgko_1_1HipExecutor" ],
      [ "HipfftError", "classgko_1_1HipfftError.html", "classgko_1_1HipfftError" ],
      [ "HipHostAllocator", "classgko_1_1HipHostAllocator.html", null ],
      [ "HiprandError", "classgko_1_1HiprandError.html", "classgko_1_1HiprandError" ],
      [ "HipsparseError", "classgko_1_1HipsparseError.html", "classgko_1_1HipsparseError" ],
      [ "HipTimer", "classgko_1_1HipTimer.html", "classgko_1_1HipTimer" ],
      [ "HipUnifiedAllocator", "classgko_1_1HipUnifiedAllocator.html", null ],
      [ "index_set", "classgko_1_1index__set.html", "classgko_1_1index__set" ],
      [ "InvalidStateError", "classgko_1_1InvalidStateError.html", "classgko_1_1InvalidStateError" ],
      [ "KernelNotFound", "classgko_1_1KernelNotFound.html", "classgko_1_1KernelNotFound" ],
      [ "LinOp", "classgko_1_1LinOp.html", "classgko_1_1LinOp" ],
      [ "LinOpFactory", "classgko_1_1LinOpFactory.html", null ],
      [ "machine_topology", "classgko_1_1machine__topology.html", "classgko_1_1machine__topology" ],
      [ "matrix_assembly_data", "classgko_1_1matrix__assembly__data.html", "classgko_1_1matrix__assembly__data" ],
      [ "matrix_data", "structgko_1_1matrix__data.html", "structgko_1_1matrix__data" ],
      [ "matrix_data_entry", "structgko_1_1matrix__data__entry.html", null ],
      [ "MetisError", "classgko_1_1MetisError.html", "classgko_1_1MetisError" ],
      [ "MpiError", "classgko_1_1MpiError.html", "classgko_1_1MpiError" ],
      [ "NotCompiled", "classgko_1_1NotCompiled.html", "classgko_1_1NotCompiled" ],
      [ "NotImplemented", "classgko_1_1NotImplemented.html", "classgko_1_1NotImplemented" ],
      [ "NotSupported", "classgko_1_1NotSupported.html", "classgko_1_1NotSupported" ],
      [ "null_deleter", "classgko_1_1null__deleter.html", "classgko_1_1null__deleter" ],
      [ "null_deleter< T[]>", "classgko_1_1null__deleter_3_01T_0f_0e_4.html", null ],
      [ "nvidia_device", "classgko_1_1nvidia__device.html", null ],
      [ "OmpExecutor", "classgko_1_1OmpExecutor.html", "classgko_1_1OmpExecutor" ],
      [ "Operation", "classgko_1_1Operation.html", "classgko_1_1Operation" ],
      [ "OutOfBoundsError", "classgko_1_1OutOfBoundsError.html", "classgko_1_1OutOfBoundsError" ],
      [ "OverflowError", "classgko_1_1OverflowError.html", "classgko_1_1OverflowError" ],
      [ "Permutable", "classgko_1_1Permutable.html", "classgko_1_1Permutable" ],
      [ "Perturbation", "classgko_1_1Perturbation.html", "classgko_1_1Perturbation" ],
      [ "PolymorphicObject", "classgko_1_1PolymorphicObject.html", "classgko_1_1PolymorphicObject" ],
      [ "precision_reduction", "classgko_1_1precision__reduction.html", "classgko_1_1precision__reduction" ],
      [ "Preconditionable", "classgko_1_1Preconditionable.html", "classgko_1_1Preconditionable" ],
      [ "ptr_param", "classgko_1_1ptr__param.html", "classgko_1_1ptr__param" ],
      [ "range", "classgko_1_1range.html", "classgko_1_1range" ],
      [ "ReadableFromMatrixData", "classgko_1_1ReadableFromMatrixData.html", "classgko_1_1ReadableFromMatrixData" ],
      [ "ReferenceExecutor", "classgko_1_1ReferenceExecutor.html", "classgko_1_1ReferenceExecutor" ],
      [ "ScaledIdentityAddable", "classgko_1_1ScaledIdentityAddable.html", "classgko_1_1ScaledIdentityAddable" ],
      [ "scoped_device_id_guard", "classgko_1_1scoped__device__id__guard.html", "classgko_1_1scoped__device__id__guard" ],
      [ "segmented_array", "structgko_1_1segmented__array.html", "structgko_1_1segmented__array" ],
      [ "span", "structgko_1_1span.html", "structgko_1_1span" ],
      [ "stopping_status", "classgko_1_1stopping__status.html", "classgko_1_1stopping__status" ],
      [ "StreamError", "classgko_1_1StreamError.html", "classgko_1_1StreamError" ],
      [ "time_point", "classgko_1_1time__point.html", null ],
      [ "Timer", "classgko_1_1Timer.html", "classgko_1_1Timer" ],
      [ "Transposable", "classgko_1_1Transposable.html", "classgko_1_1Transposable" ],
      [ "truncated", "classgko_1_1truncated.html", null ],
      [ "UnsupportedMatrixProperty", "classgko_1_1UnsupportedMatrixProperty.html", "classgko_1_1UnsupportedMatrixProperty" ],
      [ "UseComposition", "classgko_1_1UseComposition.html", "classgko_1_1UseComposition" ],
      [ "ValueMismatch", "classgko_1_1ValueMismatch.html", "classgko_1_1ValueMismatch" ],
      [ "version", "structgko_1_1version.html", "structgko_1_1version" ],
      [ "version_info", "classgko_1_1version__info.html", "classgko_1_1version__info" ],
      [ "WritableToMatrixData", "classgko_1_1WritableToMatrixData.html", "classgko_1_1WritableToMatrixData" ]
    ] ],
    [ "hwloc_obj_t", "structhwloc__obj__t.html", null ],
    [ "hwloc_obj_type_t", "structhwloc__obj__type__t.html", null ]
];